# Оценка тяжести цирроза по шкале Чайлд-Пью

## Описание
Шкала **Чайлд-Пью (Child-Pugh Score)** – это система оценки тяжести цирроза печени, которая помогает определить прогноз пациента и необходимость медицинского вмешательства.

## Параметры расчёта
Методика Чайлд-Пью основана на пяти клинических показателях:

| Параметр              | 1 балл (норма) | 2 балла (умеренно) | 3 балла (тяжело) |
|----------------------|---------------|-----------------|---------------|
| **Билирубин (мг/дл)** | <2.0          | 2.0–3.0         | >3.0          |
| **Альбумин (г/дл)**  | >3.5          | 2.8–3.5         | <2.8          |
| **INR (МНО)**        | <1.7          | 1.7–2.3         | >2.3          |
| **Асцит**            | Нет           | Умеренный      | Тяжелый      |
| **Энцефалопатия**    | Нет           | Легкая (1-2)   | Тяжёлая (3-4) |

### Итоговый балл и интерпретация
Сумма баллов определяет **класс Чайлд-Пью**, который указывает на тяжесть цирроза:

| Итоговый балл | Класс Чайлд-Пью | Прогноз (выживаемость 1 год / 2 года) |
|--------------|---------------|----------------------------------|
| 5–6         | **Класс A** (компенсированный цирроз) | 100% / 85% |
| 7–9         | **Класс B** (субкомпенсированный цирроз) | 81% / 57% |
| 10–15       | **Класс C** (декомпенсированный цирроз) | 45% / 35% |

## Использование в системе диагностики
В нашем алгоритме **Чайлд-Пью рассчитывается только если есть риск заболевания**:
- **Если цирроз маловероятен (APRI и FIB-4 в норме)** → Чайлд-Пью **не отображается**.
- **Если есть признаки цирроза или других проблем с печенью** → Чайлд-Пью рассчитывается и включается в результат.

## Пример использования
### Входные данные (JSON)
```json
{
    "Bilirubin": 2.5,
    "Albumin": 3.0,
    "INR": 1.8,
    "Ascites": "moderate",
    "Encephalopathy": "mild"
}
```

### Выходные данные (JSON)
```json
{
    "child_pugh_score": 8,
    "child_pugh_class": "B (Decompensated)"
}
```

## Когда используется шкала Чайлд-Пью?
- Для **оценки тяжести цирроза печени**.
- Для **прогноза выживаемости пациента**.
- Для **решения о необходимости трансплантации печени**.
- В комбинации с **APRI и FIB-4** для более точного диагноза.
